@@ -7,7 +7,14 @@ pub struct Error {
     pub message: String,
 }
 
-pub fn new_bad_request_error(msg: &str) -> Error {
+pub fn new_not_found_error(msg: &str) -> Error {
+    Error {
+        code: String::from("400"),
+        message: msg.to_string(),
+    }
+}
+
+pub fn new_invalid_state_error(msg: &str) -> Error {
     Error {
         code: String::from("400"),
         message: msg.to_string(),
