@@ -1,13 +1,13 @@
-use std::str::FromStr;
-
-use crate::error::Error;
-use crate::money::Money;
-use crate::shipping::FulfillmentType;
-use crate::{Checkout};
 use async_trait::async_trait;
 use rust_decimal::{prelude::FromPrimitive, Decimal};
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
+use std::str::FromStr;
+
+use crate::checkout::Checkout;
+use crate::error::Error;
+use crate::money::Money;
+use crate::shipping::FulfillmentType;
 
 #[derive(Serialize, Deserialize, JsonSchema)]
 pub enum Tax {
