@@ -6,14 +6,14 @@ pub mod checkout;
 pub mod context;
 pub mod customer;
 pub mod error;
-pub mod event;
+pub mod internal_context;
 pub mod inventory;
 pub mod invoice;
 pub mod item;
 pub mod money;
+pub mod payment;
 pub mod price;
 pub mod product;
 pub mod server;
 pub mod shipping;
-pub mod store;
 pub mod transaction;
