@@ -1,3 +1,4 @@
+use async_trait::async_trait;
 use dropshot::{ApiDescription, HttpServerStarter, ServerContext};
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
@@ -27,8 +28,9 @@ pub struct AddOrRemoveItemParams {
     pub quantity: u64,
 }
 
+#[async_trait]
 pub trait Server<'a, T: Context>: ContextProvider<'a, T> {
     type Context: ServerContext;
     fn api_description() -> ApiDescription<Self::Context>;
-    fn new_server(self, bind_address: &str) -> Result<HttpServerStarter<Self::Context>, Error>;
+    async fn new_server(self, bind_address: &str) -> Result<HttpServerStarter<Self::Context>, Error>;
 }
